<?php
namespace myretail\controllers;

use Yii;
use yii\web\Controller;
use myretail\models\ImportTransaction;
use myretail\models\SyncConfig;

class ImportTransactionController extends Controller {
    public function actionIndex() {
        $model = new ImportTransaction();
        $tipe_tabel = $model->tipe_tabel;
        $conn = SyncConfig::getConnection();
        $config = SyncConfig::find()->where(['type_con' => 'retail'])->one();
        $access_token = $config->api_key;

        if (isset($_POST['date_start'])) {$start = $_POST['date_start'];} else {$start = '0000-00-00';}
        if (isset($_POST['date_end'])) {$end = $_POST['date_end'];} else {$end = '0000-00-00';}

        $result = $model->ambilData("import", $tipe_tabel, $start, $end);

        if ($result != NULL) {
            $id_lokal = $result['sales_invoice']['id'];
            unset($result['sales_invoice']['id']);
            $response = $model->kirimData($result, $access_token);
            $simpan = $model->simpanStatus($response, $tipe_tabel, $id_lokal);
            $echo = $simpan;
            // END - proses ambil, kirim dan simpan data yang baru
        } else {
            // BEGIN - proses ambil, kirim dan simpan data yang gagal diimport
            $stmt = mysqli_query($conn, "SELECT * FROM sync_to_jurnal WHERE status_sinkron = 'proses' AND tipe_tabel = '$tipe_tabel'");
            if (mysqli_fetch_assoc($stmt) > 0) {
                $result = $model->ambilData("reimport", $tipe_tabel, $start, $end);
                for ($i=0; $i < count($result['sales_invoices']); $i++) { 
                    $id_lokal = $result['sales_invoice']['id'];
                    unset($result['sales_invoice']['id']);
                }
                $response = $model->kirimData($result, $access_token);
                $simpan = $model->simpanStatus($response, $tipe_tabel, $id_lokal);
                $echo = $simpan;
            } else {
                mysqli_query($conn, "UPDATE sync_to_jurnal SET status_sinkron = 'proses' WHERE status_sinkron = 'failed' AND tipe_tabel = '$tipe_tabel'");

                $echo = "tran";
            }
            // END - proses ambil, kirim dan simpan data yang gagal diimport
        }

        return $echo;
    }
}